@@ -1,6 +1,7 @@
 #  shadowstep/page_object/page_object_generator.py
 import inspect
 import json
+import keyword
 import logging
 import os
 import re
@@ -88,61 +89,61 @@ class PageObjectGenerator:
         """
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
         step = "Формирование title property"
-        self.logger.info(step)
+        self.logger.debug(step)
         title = self._get_title_property(ui_element_tree)
         assert title is not None, "Can't find title"
-        self.logger.info(f"{title.attrs=}")
+        self.logger.debug(f"{title.attrs=}")
 
         step = "Формирование name property"
-        self.logger.info(step)
+        self.logger.debug(step)
         name = self._get_name_property(title)
         assert name != "", "Name cannot be empty"
-        self.logger.info(f"{name=}")
+        self.logger.debug(f"{name=}")
 
         step = "Формирование имени класса"
-        self.logger.info(step)
+        self.logger.debug(step)
         page_class_name = self._normilize_to_camel_case(name)
         assert page_class_name != "", "page_class_name cannot be empty"
-        self.logger.info(f"{page_class_name=}")
+        self.logger.debug(f"{page_class_name=}")
 
         step = "Формирование recycler property"
-        self.logger.info(step)
+        self.logger.debug(step)
         recycler = self._get_recycler_property(ui_element_tree)
         # assert recycler is not None, "Can't find recycler"
         if recycler is None:
             recycler = title
-        self.logger.info(f"{recycler.attrs=}")
+        self.logger.debug(f"{recycler.attrs=}")
 
         step = "Сбор пар свитчер - якорь"
-        self.logger.info(step)
+        self.logger.debug(step)
         switcher_anchor_pairs = self._get_anchor_pairs(ui_element_tree, {"class": "android.widget.Switch"})
         # свитчеры могут быть не найдены, это нормально
-        # self.logger.info(f"{switcher_anchor_pairs=}")
-        self.logger.info(f"{len(switcher_anchor_pairs)=}")
+        # self.logger.debug(f"{switcher_anchor_pairs=}")
+        self.logger.debug(f"{len(switcher_anchor_pairs)=}")
 
         step = "Сбор summary-свойств"
-        self.logger.info(step)
+        self.logger.debug(step)
         summary_anchor_pairs = self._get_summary_pairs(ui_element_tree)
         # summary могут быть не найдены, это нормально
-        # self.logger.info(f"{summary_anchor_pairs=}")
-        self.logger.info(f"{len(summary_anchor_pairs)=}")
+        # self.logger.debug(f"{summary_anchor_pairs=}")
+        self.logger.debug(f"{len(summary_anchor_pairs)=}")
 
         step = "Сбор оставшихся обычных свойств"
-        self.logger.info(step)
+        self.logger.debug(step)
         used_elements = switcher_anchor_pairs + summary_anchor_pairs + [(title, recycler)]
         regular_properties = self._get_regular_properties(ui_element_tree, used_elements, recycler)
 
         step = "Удаление text из локаторов у элементов, которые не ищутся по text в UiAutomator2 (ex. android.widget.SeekBar)"
-        self.logger.info(step)
+        self.logger.debug(step)
         self._remove_text_from_non_text_elements(regular_properties)
 
         step = "Определение необходимости recycler"
-        self.logger.info(step)
+        self.logger.debug(step)
         need_recycler = self._is_need_recycler(recycler, regular_properties)
-        self.logger.info(f"{need_recycler=}")
+        self.logger.debug(f"{need_recycler=}")
 
         step = "Подготовка свойств для шаблона"
-        self.logger.info(step)
+        self.logger.debug(step)
         properties_for_template = self._transform_properties(
             regular_properties,
             switcher_anchor_pairs,
@@ -151,22 +152,19 @@ class PageObjectGenerator:
         )
 
         step = ""
-        self.logger.info(step)
+        self.logger.debug(step)
         skip_ids = {title.id, recycler.id}
         properties_for_template = [p for p in properties_for_template if p.get("element_id") not in skip_ids]
 
         step = "Фильтрация итоговых свойств"
-        self.logger.info(step)
-
-        switcher_ids = {s.id for _, s in switcher_anchor_pairs}
-        summary_ids = {s.id for _, s in summary_anchor_pairs}
+        self.logger.debug(step)
 
         properties_for_template = self._filter_properties(properties_for_template,
                                                           title.id,
                                                           recycler.id if recycler else None)
 
         step = "Подготовка данных для рендеринга"
-        self.logger.info(step)
+        self.logger.debug(step)
         template_data = self._prepare_template_data(
             ui_element_tree,
             title,
@@ -176,59 +174,30 @@ class PageObjectGenerator:
         )
 
         step = "Рендеринг"
-        self.logger.info(step)
+        self.logger.debug(step)
         template = self.env.get_template('page_object.py.j2')
         rendered = template.render(**template_data)
 
         step = "Формирование названия файла"
-        self.logger.info(step)
+        self.logger.debug(step)
         class_name = template_data["class_name"]
         file_name = self._class_name_to_file_name(class_name)
 
         step = "Добавление префикса к названию файла, если необходимо"
-        self.logger.info(step)
+        self.logger.debug(step)
         if filename_prefix:
             file_name = f"{filename_prefix}{file_name}"
 
         step = "Запись в файл"
-        self.logger.info(step)
+        self.logger.debug(step)
         path = os.path.join(output_dir, file_name)
         os.makedirs(os.path.dirname(path), exist_ok=True)
         with open(path, 'w', encoding='utf-8') as f:
             f.write(rendered)
-            
-        self.logger.info(f"Generated PageObject → {path}")
+
+        self.logger.debug(f"Generated PageObject → {path}")
         return path, class_name
 
-
-    def _resolve_anchor_name(self, anchor: UiElementNode, properties: List[Dict[str, Any]],
-                             used_names: Set[str]) -> str:
-        """
-        Resolves the anchor name from the given properties list or generates a fallback name.
-
-        Args:
-            anchor (UiElementNode): The anchor node.
-            properties (List[Dict[str, Any]]): List of element properties.
-            used_names (Set[str]): Set of already used property names.
-
-        Returns:
-            str: Resolved or generated anchor name.
-        """
-        self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
-
-        step = "Searching for existing property name by anchor id"
-        self.logger.debug(f"[{step}] started")
-        for prop in properties:
-            if prop.get("element_id") == anchor.id:
-                self.logger.debug(f"[{step}] found: {prop['name']}")
-                return prop["name"]
-
-        step = "Generating fallback property name"
-        self.logger.debug(f"[{step}] started")
-        name = self._generate_property_name(anchor, used_names)
-        self.logger.debug(f"[{step}] generated: {name}")
-        return name
-
     @neuro_readonly
     def _get_title_property(self, ui_element_tree: UiElementNode) -> Optional[UiElementNode]:
         """Returns the most likely title node from the tree.
@@ -281,6 +250,8 @@ class PageObjectGenerator:
         raw_name = raw_name.strip()
         if not raw_name:
             raise ValueError("Title node does not contain usable name")
+        if raw_name in keyword.kwlist:
+            raw_name = raw_name + '_'
         return raw_name
 
     @neuro_readonly
@@ -325,7 +296,7 @@ class PageObjectGenerator:
         targets = ui_element_tree.find(**target_attrs)
         if not targets:
             return []
-        # self.logger.info(f"{targets=}")
+        # self.logger.debug(f"{targets=}")
 
         step = "Process each target"
         self.logger.debug(f"[{step}] started")
@@ -333,7 +304,7 @@ class PageObjectGenerator:
             anchor = self._find_anchor_for_target(target, max_ancestor_distance, target_anchor)
             if anchor:
                 anchor_pairs.append((anchor, target))
-        # self.logger.info(f"{anchor_pairs=}")
+        # self.logger.debug(f"{anchor_pairs=}")
         return anchor_pairs
 
     @neuro_readonly
@@ -374,9 +345,9 @@ class PageObjectGenerator:
 
         step = "Iterating over ancestor.children"
         self.logger.debug(f"[{step}] started")
-        # self.logger.info(f"{ancestor.id=}, {ancestor.attrs=}")
-        # self.logger.info(f"{target.id=}, {target.attrs=}")
-        # self.logger.info(f"{ancestor.children=}")
+        # self.logger.debug(f"{ancestor.id=}, {ancestor.attrs=}")
+        # self.logger.debug(f"{target.id=}, {target.attrs=}")
+        # self.logger.debug(f"{ancestor.children=}")
 
         result = []
         # Сначала собираем всех потомков предка
@@ -386,7 +357,7 @@ class PageObjectGenerator:
 
         # Теперь фильтруем по глубине
         for node in all_descendants:
-            # self.logger.info(f"{node.id=}, {node.attrs=}")
+            # self.logger.debug(f"{node.id=}, {node.attrs=}")
             if node is target:
                 continue
 
@@ -423,22 +394,22 @@ class PageObjectGenerator:
     def _get_summary_pairs(self, ui_element_tree: UiElementNode) -> List[Tuple[UiElementNode, UiElementNode]]:
         """
         Находит пары элементов anchor-summary.
-        
+
         Args:
             ui_element_tree (UiElementNode): Дерево элементов UI
-            
+
         Returns:
             List[Tuple[UiElementNode, UiElementNode]]: Список пар (anchor, summary)
         """
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
-        
+
         # Находим все элементы, у которых в атрибутах есть "summary"
         summary_elements = []
         for element in ui_element_tree.walk():
             if any(re.search(r'\bsummary\b', str(value).lower()) for value in element.attrs.values()):
                 summary_elements.append(element)
                 self.logger.debug(f"Found summary element: {element.id}, attrs={element.attrs}")
-        
+
         # Для каждого summary элемента ищем соответствующий anchor
         summary_pairs = []
         for summary in summary_elements:
@@ -449,8 +420,8 @@ class PageObjectGenerator:
                 summary_pairs.append((anchor, summary))
             else:
                 self.logger.warning(f"No anchor found for summary element {summary.id}")
-        
-        self.logger.info(f"Total summary-anchor pairs found: {len(summary_pairs)}")
+
+        self.logger.debug(f"Total summary-anchor pairs found: {len(summary_pairs)}")
         return summary_pairs
 
     @neuro_readonly
@@ -498,7 +469,7 @@ class PageObjectGenerator:
             regular_elements.append(element)
             used_locators.add(locator_frozen)
 
-        self.logger.info(f"Total regular elements found (filtered): {len(regular_elements)}")
+        self.logger.debug(f"Total regular elements found (filtered): {len(regular_elements)}")
         return regular_elements
 
     @neuro_readonly
@@ -514,6 +485,8 @@ class PageObjectGenerator:
 
         if not camel_case:
             raise ValueError(f"Failed to normalize screen name from '{text}'")
+        if not camel_case.startswith('Page'):
+            camel_case = 'Page' + camel_case
         return camel_case
 
     @neuro_readonly
@@ -535,12 +508,12 @@ class PageObjectGenerator:
     def _remove_text_from_non_text_elements(self, elements: List[UiElementNode]) -> None:
         """
         Удаляет атрибут text из локаторов элементов, которые не должны искаться по тексту.
-        
+
         Args:
             elements (List[UiElementNode]): Список элементов для обработки
         """
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
-        
+
         for element in elements:
             if element.tag in self.BLACKLIST_NO_TEXT_CLASSES and 'text' in element.attrs:
                 self.logger.debug(f"Removing text attribute from {element.tag} element: {element.attrs.get('text')}")
@@ -555,14 +528,14 @@ class PageObjectGenerator:
                              need_recycler: bool) -> Dict[str, Any]:
         """
         Transforms structured UiElementNode data into a format compatible with the template.
-        
+
         Args:
             ui_element_tree (UiElementNode): Root UI element tree
             title (UiElementNode): Title node
             recycler (Optional[UiElementNode]): Recycler node if found
             properties (List[Dict]): Prepared properties for template
             need_recycler (bool): Whether recycler is needed
-            
+
         Returns:
             Dict[str, Any]: Data structure ready for template rendering
         """
@@ -570,7 +543,6 @@ class PageObjectGenerator:
         raw_title = self._get_name_property(title)
         translated = self._translate(raw_title)
         class_name = self._normilize_to_camel_case(translated)
-        class_name = "Page" + class_name
 
         title_locator = self._node_to_locator(title)
         recycler_locator = self._node_to_locator(recycler) if recycler else None
@@ -588,11 +560,11 @@ class PageObjectGenerator:
     def _node_to_locator(self, node: UiElementNode, only_id: bool = False) -> Dict[str, str]:
         """
         Converts UiElementNode to a locator dictionary for template.
-        
+
         Args:
             node (UiElementNode): Node to convert
             only_id (bool): Whether to return only resource-id
-            
+
         Returns:
             Dict[str, str]: Locator dictionary
         """
@@ -678,7 +650,13 @@ class PageObjectGenerator:
                 used_ids.add(anchor.id)
                 self.logger.debug(f"Added anchor: {anchor_name} → {anchor_prop['locator']}")
             else:
-                anchor_name = self._resolve_anchor_name(anchor, properties, used_names)
+                anchor_name = None
+                for p in properties:
+                    if p.get("element_id") == anchor.id:
+                        anchor_name = p.get("name")
+                        break
+                if anchor_name is None:
+                    anchor_name = self._generate_property_name(anchor, used_names)
 
             if switcher.id in used_ids:
                 continue
@@ -751,11 +729,11 @@ class PageObjectGenerator:
     def _is_scrollable_by(self, node: UiElementNode, recycler_id: Optional[str]) -> bool:
         """
         Checks if the node is scrollable by the given recycler.
-        
+
         Args:
             node (UiElementNode): Node to check
             recycler_id (Optional[str]): ID of potential recycler
-            
+
         Returns:
             bool: True if node is scrollable by the recycler
         """
@@ -768,11 +746,11 @@ class PageObjectGenerator:
     def _calculate_depth(self, anchor: UiElementNode, target: UiElementNode) -> int:
         """
         Calculates parent traversal depth between anchor and target.
-        
+
         Args:
             anchor (UiElementNode): Anchor node
             target (UiElementNode): Target node
-            
+
         Returns:
             int: Number of parent traversals needed
         """
@@ -783,21 +761,21 @@ class PageObjectGenerator:
         while current.parent:
             anchor_ancestors.append(current.parent)
             current = current.parent
-            
+
         # Find path from target to first common ancestor
         depth = 0
         current = target
         while current and current not in anchor_ancestors:
             depth += 1
             current = current.parent
-            
+
         if not current:
             # No common ancestor found, default to 0
             return 0
-            
+
         # Add distance from anchor to common ancestor
         depth += anchor_ancestors.index(current)
-        
+
         return depth
 
     @neuro_allow_edit
@@ -842,16 +820,18 @@ class PageObjectGenerator:
         while name in used_names:
             name = f"{original}_{i}"
             i += 1
+        if name in keyword.kwlist:
+            name = name + '_'
         return name
 
     @neuro_allow_edit
     def _slug_words(self, s: str) -> List[str]:
         """
         Breaks a string into lowercase slug words.
-        
+
         Args:
             s (str): Input string
-            
+
         Returns:
             List[str]: List of slug words
         """
@@ -863,10 +843,10 @@ class PageObjectGenerator:
     def _strip_package_prefix(self, resource_id: str) -> str:
         """
         Strips package prefix from resource ID.
-        
+
         Args:
             resource_id (str): Full resource ID
-            
+
         Returns:
             str: Resource ID without package prefix
         """
@@ -877,10 +857,10 @@ class PageObjectGenerator:
     def _sanitize_name(self, raw_name: str) -> str:
         """
         Creates a valid Python property name.
-        
+
         Args:
             raw_name (str): Raw property name
-            
+
         Returns:
             str: Sanitized property name
         """
@@ -912,18 +892,18 @@ class PageObjectGenerator:
     def _is_need_recycler(self, recycler: Optional[UiElementNode], regular_properties: List[UiElementNode]) -> bool:
         """
         Determines if recycler is needed by checking if any regular properties use it.
-        
+
         Args:
             recycler (Optional[UiElementNode]): Recycler node if found
             regular_properties (List[UiElementNode]): Regular properties
-            
+
         Returns:
             bool: Whether recycler is needed
         """
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
         if not recycler:
             return False
-            
+
         recycler_id = recycler.id
         return any(
             node.scrollable_parents and recycler_id in node.scrollable_parents
@@ -973,7 +953,7 @@ class PageObjectGenerator:
             # Остальная фильтрация (если добавишь еще шаги - вставь сюда)
             final.append(prop)
 
-        self.logger.info(f"{inspect.currentframe().f_code.co_name} > {final=}")
+        self.logger.debug(f"{inspect.currentframe().f_code.co_name} > {final=}")
         return final
 
     @neuro_readonly
